@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: FakeTemplateTags.py 9976 2017-05-16 06:31:28Z Lavender $
+# $Id: FakeTemplateTags.py 10146 2017-08-07 06:38:26Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,13 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-16 14:31:28 +0800 (週二, 16 五月 2017) $
-# $Revision: 9976 $
+# $Date: 2017-08-07 14:38:26 +0800 (週一, 07 八月 2017) $
+# $Revision: 10146 $
 
 from django import template
 from django.utils.safestring import mark_safe
 from django.templatetags.static import StaticNode
-from cms.templatetags.cms_tags import Placeholder, CMSToolbar
+from cms.templatetags.cms_tags import Placeholder, CMSToolbar, PageAttribute
 from sekizai.templatetags.sekizai_tags import RenderBlock
 
 register = template.Library()
@@ -33,6 +33,11 @@ class Placeholder2(Placeholder):
                                                        extra_bits, nodelist)
         return "{% placeholder '" + name + "' %}"
         
+class PageAttribute2(PageAttribute):
+    
+    def get_value(self, context, name, page_lookup):
+        return "{% page_attribute '" + name + "' %}"
+        
         
 class StaticNode2(StaticNode):
     def render(self, context):
@@ -40,5 +45,6 @@ class StaticNode2(StaticNode):
 
 register.tag('placeholder', Placeholder2)
 register.tag('static', StaticNode2)
+register.tag('page_attribute', PageAttribute2)
 
 
