@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11593 2019-05-29 06:23:49Z Lavender $
+# $Id: urls.py 11629 2019-06-11 17:44:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
-# $Revision: 11593 $ 
+# $Date: 2019-06-12 01:44:34 +0800 (週三, 12 六月 2019) $
+# $Revision: 11629 $ 
 
 from django.conf.urls import url
 
@@ -25,6 +25,4 @@ urlpatterns = [
     url(r'^comments/add$', views.CommentView.as_view(), name='addComment'),
     url(r'^comments/(?P<pk>\d+)/hide$', 
         views.CommentHideView.as_view(), name='hideComment'),
-    url(r'^webhook/', 
-        views.CommentWebHookView.as_view(), name='commentWebhook')
 ]
