@@ -12,7 +12,7 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-21 03:48:58 +0900 (週日, 21 四月 2019) $
+# $Date: 2019-04-21 02:48:58 +0800 (週日, 21 四月 2019) $
 # $Revision: 11474 $
 
 import datetime
@@ -139,9 +139,9 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                     fail_silently=False
                 )
             
-            replaceStr = Context({
+            replaceStr = {
                 'email': email.email,
-            })
+            }
             if not form:
                 mail = get_template('landing/ThankEmail.txt')
                 
@@ -159,7 +159,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                 title = landingForm.email_subject
                 send_mail(
                     title,
-                    mail.render(replaceStr),
+                    mail.render(Context(replaceStr)),
                     settings.EMAIL_HOST_USER,
                     [email.email,],
                     fail_silently=False
